@@ -36,4 +36,9 @@
 /* LibGTop server version, increased each time the protocol changes. */
 #undef LIBGTOP_SERVER_VERSION
 
+/* Location of KDE menus */
+#undef KDE_MENUDIR
+#undef KDE_ICONDIR
+#undef KDE_MINI_ICONDIR
+
 #undef HAVE_ZVT_TERM_RESET
