@@ -306,12 +306,22 @@ void cb_about (AppletWidget *applet, gpointer data)
 {
     GtkWidget *about;
     static const gchar *authors[] = {
-			    "Iigo Serna <inigo@gaztelan.bi.ehu.es>",
+			    /* languages which use font encodings that can't
+			     * display spanish '' should use 'n' instead */
+			    N_("Iigo Serna <inigo@gaztelan.bi.ehu.es>"),
 			    NULL
     };
 
+#ifdef ENABLE_NLS
+    {
+	int i=0;
+	
+	while (authors[i] != NULL) { authors[i]=_(authors[i]); i++; }
+    }
+#endif
+
     about = gnome_about_new (_("Another Clock Applet"), "0.2",
-			     "(C) 1999 the Free Software Foundation",
+			     _("(C) 1999 the Free Software Foundation"),
                     	     authors,
                     	     _("An analog clock similar to that in CDE panel."),
                     	     NULL);
