@@ -135,7 +135,9 @@ battery_update (gpointer data)
   /*
    * Warn if the battery is low.
    */
-  if (bat->low_warn_enable && (percentage <= bat->low_warn_val)
+  if (bat->low_warn_enable
+      && (! ac_online)
+      && (percentage <= bat->low_warn_val)
       && (! bat->warned))
     {
       gnome_warning_dialog (_("The battery is low."));
