@@ -33,7 +33,7 @@ struct _Printer {
 };
 
 enum {
-  TARGET_URI_LIST,
+  TARGET_URI_LIST
 };
 
 void position_label (GtkWidget *label, gpointer data);
@@ -147,14 +147,9 @@ printer_widget (Printer *pr)
 static void
 applet_set_default_back(Printer *pr)
 {
-	GtkStyle *ns;
-
-	ns = gtk_style_new();
-
-	gtk_style_ref(ns);
-	gtk_widget_set_style(pr->printer, ns);
-	gtk_style_unref(ns);
+	g_return_if_fail (pr->printer != NULL);
 
+	gtk_widget_set_rc_style(pr->printer);
 	gtk_widget_queue_draw(GTK_WIDGET(pr->printer));
 }
 
