@@ -515,10 +515,25 @@ util_get_atom(Window win, gchar *atom, Atom type, gint *size)
 	}
       else /*format_ret==8*/
 	{
-          *size = num_ret;
-          data = g_malloc(num_ret);
-          if (data)
-	    memcpy(data, retval, num_ret);
+	  if (type_ret == XA_STRING) {
+	    *size = num_ret;
+	    data = g_malloc(num_ret);
+	    if (data)
+	      memcpy(data, retval, num_ret);
+	  } else {
+	    gchar **list;
+	    gint count;
+	    count = gdk_text_property_to_text_list (
+			type_ret, 8, retval, num_ret, &list);
+	    if (count > 0) {
+	      data = g_strdup (list[0]);
+	      gdk_free_text_list (list);
+	      *size = strlen (data);
+	    } else {
+	      data = NULL;
+	      *size = 0;
+	    }
+	  }
 	}
       XFree(retval);
       return data;
@@ -1042,6 +1057,13 @@ task_get_info(Task *t)
     g_free(t->name);
   t->name = NULL;
   name = util_get_atom(t->win, "WM_NAME", XA_STRING, &size);
+  if (name == NULL) 
+    {
+    Atom atom_ctext;
+    atom_ctext = XInternAtom(GDK_DISPLAY(), "COMPOUND_TEXT",
+			     False);
+    name = util_get_atom(t->win, "WM_NAME", atom_ctext, &size);
+    }
   if (name)
     {
       t->name = g_malloc(size + 1);
@@ -1591,6 +1613,10 @@ main(int argc, char *argv[])
   config.show_arrow = gnome_config_get_int("stuff/show_arrow=1");
   config.fixed_tasklist = gnome_config_get_int("stuff/fixed_tasklist=0");
   config.reverse_order = gnome_config_get_bool("stuff/reverse_order=false");
+  config.pager_w_0 = gnome_config_get_int("gnome_pager/stuff/pager_w_0=31");
+  config.pager_h_0 = gnome_config_get_int("gnome_pager/stuff/pager_h_0=22");
+  config.pager_w_1 = gnome_config_get_int("gnome_pager/stuff/pager_w_1=62");
+  config.pager_h_1 = gnome_config_get_int("gnome_pager/stuff/pager_h_1=44");
 
   gdk_error_warnings = 0;  
   get_desktop_names();
@@ -2474,11 +2500,9 @@ set_task_info_to_button(Task *t)
     }
   
     /*if the size is too much and we can reduce it, do it*/
-    /*FIXME: this  won't work with i18n (with multibyte characters)
-      properly*/
     if(req.width > mw && label && (!t->name || *t->name)) {
 	    int len;
-	    char *str;
+	    GdkWChar *wstr;
 	    int button_width;
 
 	    gtk_label_set_text (GTK_LABEL(label), "");
@@ -2488,29 +2512,45 @@ set_task_info_to_button(Task *t)
 		    len = strlen(t->name);
 	    else
 		    len = 3; /*strlen("???");*/
-	    
+
 	    len--;
-	    str = g_malloc(len+4);
-	    if(t->name)
-		    strcpy(str,t->name);
-	    else
-		    strcpy(str,"???");
-	    strcat(str,"..");
+	    wstr = g_new(GdkWChar, len + 4);
+	    if (t->name) 
+	      {
+		len = gdk_mbstowcs(wstr, t->name, len);
+		if (len < 0)
+		  len = 0;
+	      }
+	    else 
+	      {
+		wstr[0] = wstr[1] = wstr[2] = '?'; 
+		wstr[3] = '\0'; /* wcscpy(wstr,"???");*/
+		len = 3;
+	      }
+	    wstr[len] = wstr[len+1] = '.';  
+	    wstr[len+2] = '\0'; /*wcscat(wstr,"..");*/
+	    len--;
+
 	    for(;len>0;len--) {
 		    int label_len;
-		    str[len]='.';
-		    str[len+3]='\0';
+		    wstr[len] = '.';
+		    wstr[len + 3] = '\0';
 
-		    label_len = gdk_string_width
-			    (GTK_WIDGET (label)->style->font, str);
+		    label_len = gdk_text_width_wc
+		      (GTK_WIDGET(label)->style->font, wstr, len + 3);
 		    if(label_len+req.width<=mw)
 			    break;
 	    }
 	    if(len<=0)
 		    gtk_label_set_text (GTK_LABEL(label), "");
 	    else
-		    gtk_label_set_text (GTK_LABEL(label), str);
-	    g_free(str);
+	      {
+		gchar *str;
+		str = gdk_wcstombs(wstr);
+		gtk_label_set_text (GTK_LABEL(label), str);
+		g_free(str);
+	      }
+	    g_free(wstr);
     }
 }
 
