@@ -1950,6 +1950,7 @@ new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry)
 	int i = 0;
 	struct terminal_config *cfg;
 	int width, height;
+	int xpos, ypos;
 	gboolean term_found = FALSE;
 		
 	/* FIXME: is seems like a lot of this stuff should be done by apply_changes instead */
@@ -2025,23 +2026,13 @@ new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry)
 	 * Handle geometry specification; height and width are in
 	 * terminal rows and columns
 	 */
-	term = (ZvtTerm *)zvt_term_new();
-	if ((zvt_term_get_capabilities (term) & ZVT_TERM_PIXMAP_SUPPORT) != 0){
-		zvt_pixmap_support = TRUE;
-	}
-	gtk_object_set_data(GTK_OBJECT(app), "term", term);
-	gtk_widget_grab_focus(GTK_WIDGET(term));
 
 	width=80;
 	height=24;
-
+	xpos=-1;
+	ypos=-1;
 	if (geometry) {
-		int xpos, ypos;
-
 		gnome_parse_geometry (geometry, &xpos, &ypos, &width, &height);
-
-		if (xpos != -1 && ypos != -1)
-			gtk_widget_set_uposition (GTK_WIDGET (app), xpos, ypos);
 		if (width == -1 || height == -1) {
 			width=80;
 			height=24;
@@ -2049,7 +2040,17 @@ new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry)
 		/* Only the first window gets --geometry treatment for now */
 		geometry = NULL;
 	}
-	zvt_term_set_size(term, width, height);
+
+	term = (ZvtTerm *)zvt_term_new_with_size(width, height);
+	if (xpos != -1 && ypos != -1)
+		gtk_widget_set_uposition (GTK_WIDGET (app), xpos, ypos);
+
+	if ((zvt_term_get_capabilities (term) & ZVT_TERM_PIXMAP_SUPPORT) != 0){
+		zvt_pixmap_support = TRUE;
+	}
+	gtk_object_set_data(GTK_OBJECT(app), "term", term);
+	gtk_widget_grab_focus(GTK_WIDGET(term));
+
 	gtk_widget_show (GTK_WIDGET (term));
 
 	gtk_signal_connect_object(GTK_OBJECT(app),"configure_event",
@@ -2299,7 +2300,7 @@ save_session (GnomeClient *client, gint phase, GnomeSaveStyle save_style,
 		 * we can't use gnome_geometry_string because we need
 		 * to calculate the terminal, not window size
 		 */
-		gdk_window_get_root_origin (top->window, &x, &y);
+		gdk_window_get_origin (top->window, &x, &y);
 
 		width = 
 		  (GTK_WIDGET (term)->allocation.width - 
