@@ -134,7 +134,7 @@ GnomeUIInfo filemenu[] = {
 
 	{GNOME_APP_UI_ITEM, 
 	 N_("_Add Bookmark"), N_("Add bookmark"),
-         bookmark_cb, NULL, NULL, 
+         (gpointer)bookmark_cb, NULL, NULL, 
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE,
 	 0, 0, NULL},
 
@@ -159,12 +159,12 @@ GnomeUIInfo helpmenu[] = {
 GnomeUIInfo windowmenu[] = {
 	{GNOME_APP_UI_ITEM, 
 	 N_("_History"), N_("Show History Window"),
-         ghelpShowHistory, NULL, NULL, 
+         (gpointer)ghelpShowHistory, NULL, NULL, 
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{GNOME_APP_UI_ITEM, 
 	 N_("_Bookmarks"), N_("Show Bookmarks Window"),
-         ghelpShowBookmarks, NULL, NULL, 
+         (gpointer)ghelpShowBookmarks, NULL, NULL, 
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	 GNOMEUIINFO_END
@@ -211,6 +211,54 @@ GnomeUIInfo toolbar[] = {
 /**********************************************************************/
 
 
+/* stupid function to handle fact XmHTML doesn't un-escape & strings */
+/* in URL we get passed back!                                        */
+static gchar *
+unescape_url ( gchar *ref ) {
+    gchar *s, *ns;
+    gchar *newref;
+
+
+    /* go through and replace any of following with unescaped equivs */
+
+    if (!ref)
+	return NULL;
+
+    newref = g_strdup (ref);
+    for (s=ref, ns=newref; *s; ) {
+
+	if (*s != '&') {
+	    *ns = *s;
+	    ns++;
+	    s++;
+	    continue;
+	} else {
+
+	    if (!g_strncasecmp (s, "&gt;", 4)) {
+		*ns = '>';
+		s+=4;
+	    } else if (!g_strncasecmp (s, "&lt;", 4)) {
+		*ns = '<';
+		s+=4;
+	    } else if (!g_strncasecmp (s, "&amp;", 5)) {
+		*ns = '&';
+		s+=5;
+	    } else {
+		*ns = *s;
+		s++;
+	    }
+
+	    ns++;
+	    continue;
+	}
+    }
+
+    *ns = '\0';
+
+    return newref;
+}
+
+
 /**********************************************************************/
 
 /* Callbacks */
@@ -279,9 +327,19 @@ quit_cb (void)
 static void
 xmhtml_activate(GtkWidget *w, XmHTMLAnchorCallbackStruct *cbs, HelpWindow win)
 {
-        g_message("TAG CLICKED: %s", cbs->href);
 
-	helpWindowShowURL(win, cbs->href, TRUE, TRUE);
+
+    g_message("TAG CLICKED: %s", cbs->href);
+    
+    if (cbs->href) {
+	gchar *s;
+
+	s = unescape_url(cbs->href);
+	
+	helpWindowShowURL(win, s, TRUE, TRUE);
+	
+	g_free(s);
+    }
 }
 
 static void
@@ -289,7 +347,11 @@ anchorTrack(GtkWidget *w, XmHTMLAnchorCallbackStruct *cbs, HelpWindow win)
 {
 	gnome_appbar_pop(GNOME_APPBAR(win->appBar));
 	if (cbs->href) {
-		gnome_appbar_push(GNOME_APPBAR(win->appBar), cbs->href);
+	    gchar *s;
+
+	    s = unescape_url(cbs->href);
+	    gnome_appbar_push(GNOME_APPBAR(win->appBar), s);
+	    g_free (s);
 	}
 }
 
@@ -645,7 +707,7 @@ static void dndDrop(GtkWidget *widget, GdkDragContext *context, gint x, gint y,
     GList *urls;
     
     if (data->data) {
-	GList *urls = gnome_uri_list_extract_uris (data->data);
+	GList *urls = gnome_uri_list_extract_uris ((gchar *)data->data);
 
 	if (urls)
 	    helpWindowShowURL(win, (char *)urls->data, TRUE, TRUE);
@@ -814,7 +876,7 @@ helpWindowShowURL(HelpWindow win, gchar *ref,
 	if (visitURL(win, ref, useCache, addToQueue, TRUE)) {
 		GtkWidget *msg;
 
-		snprintf(err, sizeof(err), _("Error loading document:\n\n%s"),
+		snprintf(err, sizeof(err), _("Error loading document:\n\n%s\n\nYou probably don't\nhave this documentation\ninstalled on your system."),
 			 ref);
 		msg = gnome_message_box_new(err, GNOME_MESSAGE_BOX_ERROR,
 					   _("Ok"), NULL);
