@@ -152,6 +152,8 @@ get_applet_goad_id_from_dentry(GnomeDesktopEntry *ii)
 	int i;
 	int constantlen = strlen("--activate-goad-server");
 	char *goad_id=NULL;
+	if (!ii || !ii->exec)
+		return NULL;
 	/*FIXME:
 	  this is a horrible horrible hack and should be taken out
 	  and shot, once we add proper way to do this*/
@@ -2913,6 +2915,8 @@ create_rh_menu(int dofork)
 	if(dofork) {
 		int i = fork();
 		if(i>0) {
+			g_free (userrh);
+			g_free (rhdir);
 			wait(NULL);
 			return;
 		/*if fork failed, no need to worry we'll just do it
